==> vue-testing-library-0.1.14.tgz: package/npm/__tests__/stopwatch.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

var _StopWatch = require('./components/StopWatch.vue');

var _StopWatch2 = _interopRequireDefault(_StopWatch);

var _ = require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var wait = function wait(time) {
  return new _promise2.default(function (resolve) {
    return setTimeout(resolve, time);
  });
};

test('unmounts a component', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
  var _render, unmount, getByText, wrapper;

  return _regenerator2.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          jest.spyOn(console, 'error').mockImplementation(function () {});

          _render = (0, _.render)(_StopWatch2.default), unmount = _render.unmount, getByText = _render.getByText, wrapper = _render.wrapper;

          _.Simulate.click(getByText('start'));

          unmount();
          expect(wrapper.vm._isDestroyed).toBe(true);

          _context.next = 7;
          return wait();

        case 7:
          expect(console.error).not.toHaveBeenCalled();

        case 8:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined);
})));

==> vue-testing-library-0.2.1.tgz: package/npm/__tests__/stopwatch.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

var _StopWatch = require('./components/StopWatch.vue');

var _StopWatch2 = _interopRequireDefault(_StopWatch);

var _ = require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var wait = function wait(time) {
  return new _promise2.default(function (resolve) {
    return setTimeout(resolve, time);
  });
};

test('unmounts a component', (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
  var _render, unmount, isUnmounted, getByText, wrapper;

  return _regenerator2.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          jest.spyOn(console, 'error').mockImplementation(function () {});

          _render = (0, _.render)(_StopWatch2.default), unmount = _render.unmount, isUnmounted = _render.isUnmounted, getByText = _render.getByText, wrapper = _render.wrapper;

          _.Simulate.click(getByText('start'));

          unmount();
          expect(isUnmounted()).toBe(true);

          _context.next = 7;
          return wait();

        case 7:
          expect(console.error).not.toHaveBeenCalled();

        case 8:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined);
})));
